'use client'
import { deleteCase } from "@/app/lib/cases/action";
import DataTable from "@/components/tables/DataTable";
import { DeleteIcon, EditIcon } from "@chakra-ui/icons";
import { Button, Flex, Icon, useColorModeValue, useToast } from "@chakra-ui/react";
import { useRouter } from "next/navigation";
import { CaseInterface } from "../type/case";
import { columnsDataBlocks } from "../variables/columnsBlock";
import AddButton from "@/components/buttons/add";
import { extractPagination } from "@/utils/common";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";

export interface Role {
  id: number;
  name: string;
}

interface CaseTableProps {
  data: { data: CaseInterface[] };
}

const CaseTable: React.FC<CaseTableProps> = ({ data }) => {
  const { currentUser } = useGeneral();
  const toast = useToast();
  const router = useRouter();
  const brandColor = useColorModeValue("brand.500", "white");

  const paginationData = extractPagination(data);

  const deleteUser = async (id: number) => {
    const res = await deleteCase(id);
    if (res?.status == 200) {
      toast({
        title: "Success",
        description: res.message,
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      router.refresh();
    } else {
      toast({
        title: "Error",
        description: res.message,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };

  const handleAddClick = () => {
    router.push("/admin/cases/create");
  };

  const handleEditClick = (id: number) => {
    router.push(`/admin/cases/edit/${id}`);
  };

  const action = (user: any) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "case", "edit") && (
        <Button
          variant="blank"
          onClick={() => handleEditClick(user)}
          w="37px"
          h="37px"
          borderRadius="10px">
          <Icon as={EditIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}
      {hasPermission(currentUser.permissions, "case", "delete") && (
        <Button
          variant="blank"
          onClick={() => deleteUser(user)}
          w="37px"
          h="37px"
          borderRadius="10px">
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}
    </Flex>
  );

  return (
    <>
      <DataTable
        addButton={hasPermission(currentUser.permissions, "case", "create") && <AddButton onClick={handleAddClick} />}
        columnsData={columnsDataBlocks}
        tableData={data?.data as unknown as CaseInterface[]}
        paginate={paginationData}
        isSelectable={false}
        showPageSize={false}
        actionSlot={(user: any) => action(user)}
      />
    </>
  );
};

export default CaseTable;
